@@ -144,11 +144,18 @@ impl<'de> Deserialize<'de> for CommandDataOption {
                     let key = match map.next_key() {
                         Ok(Some(key)) => key,
                         Ok(None) => break,
+                        #[cfg(feature = "tracing")]
                         Err(why) => {
                             map.next_value::<IgnoredAny>()?;
 
                             tracing::trace!("ran into an unknown key: {:?}", why);
 
+                            continue;
+                        }
+                        #[cfg(not(feature = "tracing"))]
+                        Err(_) => {
+                            map.next_value::<IgnoredAny>()?;
+
                             continue;
                         }
                     };
