@@ -1,7 +1,7 @@
 use crate::{application::interaction::InteractionType, id::InteractionId, user::User};
 use serde::{Deserialize, Serialize};
 
-#[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
+#[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct MessageInteraction {
     pub id: InteractionId,
     #[serde(rename = "type")]
