@@ -58,6 +58,7 @@ mod tests {
             self_deaf: false,
             self_mute: false,
             self_stream: false,
+            self_video: false,
             session_id: "a".to_owned(),
             suppress: false,
             token: None,
@@ -73,7 +74,7 @@ mod tests {
                 },
                 Token::Struct {
                     name: "VoiceState",
-                    len: 12,
+                    len: 13,
                 },
                 Token::Str("channel_id"),
                 Token::None,
@@ -139,6 +140,8 @@ mod tests {
                 Token::Bool(false),
                 Token::Str("self_stream"),
                 Token::Bool(false),
+                Token::Str("self_video"),
+                Token::Bool(false),
                 Token::Str("session_id"),
                 Token::Str("a"),
                 Token::Str("suppress"),
@@ -199,6 +202,7 @@ mod tests {
             self_deaf: false,
             self_mute: false,
             self_stream: false,
+            self_video: false,
             session_id: "asdasdas1da98da2b3ab3a".to_owned(),
             suppress: false,
             token: None,
@@ -218,7 +222,7 @@ mod tests {
                 },
                 Token::Struct {
                     name: "VoiceState",
-                    len: 11,
+                    len: 12,
                 },
                 Token::Str("channel_id"),
                 Token::None,
@@ -285,6 +289,8 @@ mod tests {
                 Token::Bool(false),
                 Token::Str("self_stream"),
                 Token::Bool(false),
+                Token::Str("self_video"),
+                Token::Bool(false),
                 Token::Str("session_id"),
                 Token::Str("asdasdas1da98da2b3ab3a"),
                 Token::Str("suppress"),
