@@ -4,6 +4,7 @@ use crate::{
         message::sticker::StickerFormatType, permission_overwrite::PermissionOverwrite,
         stage_instance::PrivacyLevel, thread::AutoArchiveDuration,
     },
+    datetime::Timestamp,
     guild::{
         DefaultMessageNotificationLevel, ExplicitContentFilter, MfaLevel, NSFWLevel, Permissions,
         VerificationLevel,
@@ -160,6 +161,15 @@ pub enum AuditLogChange {
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
         old: Option<u64>,
     },
+    /// Member timeout state changed.
+    CommunicationDisabledUntil {
+        /// New timeout timestamp.
+        #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
+        new: Option<Timestamp>,
+        /// Old timeout timestamp.
+        #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
+        old: Option<Timestamp>,
+    },
     /// Whether a member is guild deafened.
     Deaf {
         /// Whether a member is now guild deafened.
@@ -500,6 +510,7 @@ pub enum AuditLogChange {
         old: Option<String>,
     },
     /// Role was added to a user.
+    #[serde(rename = "$add")]
     RoleAdded {
         /// Minimal information about a added role.
         #[serde(default, rename = "new_value", skip_serializing_if = "Vec::is_empty")]
@@ -509,6 +520,7 @@ pub enum AuditLogChange {
         old: Vec<AffectedRole>,
     },
     /// Role was removed from a user.
+    #[serde(rename = "$remove")]
     RoleRemoved {
         /// Minimal information about a removed role.
         #[serde(default, rename = "new_value", skip_serializing_if = "Vec::is_empty")]
@@ -698,6 +710,9 @@ impl AuditLogChange {
             Self::ChannelId { .. } => AuditLogChangeKey::ChannelId,
             Self::Code { .. } => AuditLogChangeKey::Code,
             Self::Color { .. } => AuditLogChangeKey::Color,
+            Self::CommunicationDisabledUntil { .. } => {
+                AuditLogChangeKey::CommunicationDisabledUntil
+            }
             Self::Deaf { .. } => AuditLogChangeKey::Deaf,
             Self::DefaultAutoArchiveDuration { .. } => {
                 AuditLogChangeKey::DefaultAutoArchiveDuration
@@ -782,6 +797,7 @@ mod tests {
     assert_fields!(AuditLogChange::ChannelId: new);
     assert_fields!(AuditLogChange::Code: new);
     assert_fields!(AuditLogChange::Color: new, old);
+    assert_fields!(AuditLogChange::CommunicationDisabledUntil: new, old);
     assert_fields!(AuditLogChange::Deaf: new, old);
     assert_fields!(AuditLogChange::DefaultMessageNotifications: new, old);
     assert_fields!(AuditLogChange::Deny: new);
