@@ -37,7 +37,7 @@ mod tests {
         let emoji = Emoji {
             animated: false,
             available: true,
-            id: EmojiId(100_000_000_000_000_000),
+            id: EmojiId::new(100_000_000_000_000_000).expect("non zero"),
             managed: false,
             name: "test".to_owned(),
             require_colons: true,
@@ -47,10 +47,10 @@ mod tests {
                 avatar: None,
                 banner: None,
                 bot: false,
-                discriminator: "0001".to_owned(),
+                discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId(1),
+                id: UserId::new(1).expect("non zero"),
                 locale: None,
                 mfa_enabled: None,
                 name: "test".to_owned(),
@@ -113,20 +113,20 @@ mod tests {
         let emoji = Emoji {
             animated: false,
             available: true,
-            id: EmojiId(100_000_000_000_000_000),
+            id: EmojiId::new(100_000_000_000_000_000).expect("non zero"),
             managed: false,
             name: "test".to_owned(),
             require_colons: true,
-            roles: vec![RoleId(1)],
+            roles: vec![RoleId::new(1).expect("non zero")],
             user: Some(User {
                 accent_color: None,
                 avatar: None,
                 banner: None,
                 bot: false,
-                discriminator: "0001".to_owned(),
+                discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId(1),
+                id: UserId::new(1).expect("non zero"),
                 locale: None,
                 mfa_enabled: None,
                 name: "test".to_owned(),
