@@ -95,6 +95,8 @@ pub struct Guild {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub permissions: Option<Permissions>,
     pub preferred_locale: String,
+    /// Whether the premium progress bar is enabled in the guild.
+    pub premium_progress_bar_enabled: bool,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub premium_subscription_count: Option<u64>,
     #[serde(default)]
@@ -159,6 +161,7 @@ impl<'de> Deserialize<'de> for Guild {
             Owner,
             Permissions,
             PreferredLocale,
+            PremiumProgressBarEnabled,
             PremiumSubscriptionCount,
             PremiumTier,
             Presences,
@@ -218,6 +221,7 @@ impl<'de> Deserialize<'de> for Guild {
                 let mut owner_id = None;
                 let mut permissions = None::<Option<_>>;
                 let mut preferred_locale = None;
+                let mut premium_progress_bar_enabled = None;
                 let mut premium_subscription_count = None::<Option<_>>;
                 let mut premium_tier = None;
                 let mut presences = None;
@@ -482,6 +486,15 @@ impl<'de> Deserialize<'de> for Guild {
 
                             preferred_locale = Some(map.next_value()?);
                         }
+                        Field::PremiumProgressBarEnabled => {
+                            if premium_progress_bar_enabled.is_some() {
+                                return Err(DeError::duplicate_field(
+                                    "premium_progress_bar_enabled",
+                                ));
+                            }
+
+                            premium_progress_bar_enabled = Some(map.next_value()?);
+                        }
                         Field::PremiumSubscriptionCount => {
                             if premium_subscription_count.is_some() {
                                 return Err(DeError::duplicate_field("premium_subscription_count"));
@@ -623,6 +636,8 @@ impl<'de> Deserialize<'de> for Guild {
                 let roles = roles.ok_or_else(|| DeError::missing_field("roles"))?;
                 let system_channel_flags = system_channel_flags
                     .ok_or_else(|| DeError::missing_field("system_channel_flags"))?;
+                let premium_progress_bar_enabled = premium_progress_bar_enabled
+                    .ok_or_else(|| DeError::missing_field("premium_progress_bar_enabled"))?;
                 let verification_level = verification_level
                     .ok_or_else(|| DeError::missing_field("verification_level"))?;
 
@@ -691,12 +706,13 @@ impl<'de> Deserialize<'de> for Guild {
                     ?owner,
                     ?permissions,
                     ?preferred_locale,
-                    ?premium_subscription_count,
+                    ?premium_progress_bar_enabled,
                 );
 
                 // Split in two due to generic impl only going up to 32.
                 #[cfg(feature = "tracing")]
                 tracing::trace!(
+                    ?premium_subscription_count,
                     ?premium_tier,
                     ?presences,
                     ?rules_channel_id,
@@ -799,6 +815,7 @@ impl<'de> Deserialize<'de> for Guild {
                     owner,
                     permissions,
                     preferred_locale,
+                    premium_progress_bar_enabled,
                     premium_subscription_count,
                     premium_tier,
                     presences,
@@ -850,6 +867,7 @@ impl<'de> Deserialize<'de> for Guild {
             "owner_id",
             "permissions",
             "preferred_locale",
+            "premium_progress_bar_enabled",
             "premium_subscription_count",
             "premium_tier",
             "presences",
@@ -918,6 +936,7 @@ mod tests {
             owner: Some(false),
             permissions: Some(Permissions::SEND_MESSAGES),
             preferred_locale: "en-us".to_owned(),
+            premium_progress_bar_enabled: false,
             premium_subscription_count: Some(3),
             premium_tier: PremiumTier::Tier1,
             presences: Vec::new(),
@@ -942,7 +961,7 @@ mod tests {
             &[
                 Token::Struct {
                     name: "Guild",
-                    len: 44,
+                    len: 45,
                 },
                 Token::Str("afk_channel_id"),
                 Token::Some,
@@ -1028,6 +1047,8 @@ mod tests {
                 Token::Str("2048"),
                 Token::Str("preferred_locale"),
                 Token::Str("en-us"),
+                Token::Str("premium_progress_bar_enabled"),
+                Token::Bool(false),
                 Token::Str("premium_subscription_count"),
                 Token::Some,
                 Token::U64(3),
